# Installation

The package can be installed from [PyPI](https://pypi.org/) with the following command:

    pip install solposx

Some of the solar position algorithms are imported from the solar energy modeling library [pvlib](https://pvlib-python.readthedocs.io/en/stable/) which can be installed by the command:

    pip install pvlib
